@@ -97,7 +97,10 @@ class BaseDataManager(object):
         if self.default_limit >= count:
             skip, link = self._generate_file_link(skip, f'{filename}.tsv', fields)
             links.append(link)
-            delete_file(f'{filename}.tsv')
+            try:
+                delete_file(f'{filename}.tsv')
+            except FileNotFoundError:
+                pass
         else:
             delimiters = []
             for chunk in chunk_by_items(
